@@ -21,51 +21,7 @@ require 'puppet/util/run_mode'
 require 'puppet/external/pson/common'
 require 'puppet/external/pson/version'
 require 'puppet/external/pson/pure'
-
-# When running within puppetserver, the gettext-setup gem might not be available, so
-# we need to skip initializing i18n functionality and stub out methods normally
-# supplied by gettext-setup. Can be removed in Puppet 5. See PUP-7116.
-begin
-  require 'gettext-setup'
-  require 'locale'
-
-  # e.g. ~/code/puppet/locales. Also when running as a gem.
-  local_locale_path = File.absolute_path('../locales', File.dirname(__FILE__))
-  # e.g. /opt/puppetlabs/puppet/share/locale
-  posix_system_locale_path = File.absolute_path('../../../share/locale', File.dirname(__FILE__))
-  # e.g. C:\Program Files\Puppet Labs\Puppet\puppet\share\locale
-  win32_system_locale_path = File.absolute_path('../../../../../puppet/share/locale', File.dirname(__FILE__))
-
-  if File.exist?(local_locale_path)
-    locale_path = local_locale_path
-  elsif Puppet::Util::Platform.windows? && File.exist?(win32_system_locale_path)
-    locale_path = win32_system_locale_path
-  elsif !Puppet::Util::Platform.windows? && File.exist?(posix_system_locale_path)
-    locale_path = posix_system_locale_path
-  else
-    # We couldn't load our locale data.
-    raise LoadError, "could not find locale data, skipping Gettext initialization"
-  end
-
-  Puppet::LOCALE_PATH = locale_path
-  Puppet::GETTEXT_AVAILABLE = true
-rescue LoadError
-  def _(msg)
-    msg
-  end
-
-  def n_(*args, &block)
-    # assume two string args (singular and plural English form) and the count
-    # to pluralize on
-    plural = args[2] == 1 ? args[0] : args[1]
-    # if a block is passed, prefer that over the string selection above
-    block ? block.call : plural
-  end
-
-  Puppet::LOCALE_PATH = nil
-  Puppet::GETTEXT_AVAILABLE = false
-end
-
+require 'puppet/gettext/config'
 
 
 #------------------------------------------------------------
@@ -86,14 +42,11 @@ module Puppet
   require 'puppet/environments'
 
   class << self
-    if Puppet::GETTEXT_AVAILABLE && Puppet::LOCALE_PATH
-      if GettextSetup.method(:initialize).parameters.count == 1
-        # Will load translations from PO files only
-        GettextSetup.initialize(Puppet::LOCALE_PATH)
-      else
-        GettextSetup.initialize(Puppet::LOCALE_PATH, :file_format => :mo)
-      end
-      FastGettext.locale = GettextSetup.negotiate_locale(Locale.current.language)
+    gettext_config_file = Puppet::GettextConfig.puppet_locale_path
+    unless Puppet::GettextConfig.initialize(gettext_config_file, Puppet::GettextConfig.translation_mode(gettext_config_file))
+      # Stub out gettext's `_` and `n_()` methods, which attempt to load translations,
+      # with versions that do nothing
+      require 'puppet/gettext/stubs'
     end
 
     include Puppet::Util
@@ -267,6 +220,7 @@ module Puppet
         Puppet::Network::HTTP::NoCachePool.new
       },
       :ssl_host => proc { Puppet::SSL::Host.localhost },
+      :certificate_revocation => proc { Puppet[:certificate_revocation] },
       :plugins => proc { Puppet::Plugins::Configuration.load_plugins }
     }
   end
