@@ -1,4 +1,5 @@
 require 'puppet/util/logging'
+require 'puppet/module/task'
 require 'json'
 require 'semantic_puppet/gem_version'
 
@@ -79,7 +80,7 @@ class Puppet::Module
     end
   end
 
-  attr_reader :name, :environment, :path, :metadata
+  attr_reader :name, :environment, :path, :metadata, :tasks
   attr_writer :environment
 
   attr_accessor :dependencies, :forge_name
@@ -97,15 +98,7 @@ class Puppet::Module
     @absolute_path_to_manifests = Puppet::FileSystem::PathPattern.absolute(manifests)
 
     # i18n initialization for modules
-    if Puppet::GETTEXT_AVAILABLE
-      begin
-        initialize_i18n
-      rescue Exception => e
-        Puppet.warning _("GettextSetup initialization for %{module_name} failed with: %{error_message}") % { module_name: name, error_message: e.message }
-      end
-    else
-      Puppet.warning _("GettextSetup is not available, skipping GettextSetup initialization for %{module_name}.") % { module_name: name }
-    end
+    initialize_i18n unless Puppet[:disable_i18n]
   end
 
   # @deprecated The puppetversion module metadata field is no longer used.
@@ -169,6 +162,39 @@ class Puppet::Module
     end
   end
 
+  def tasks_directory
+    subpath("tasks")
+  end
+
+  def tasks
+    return @tasks if instance_variable_defined?(:@tasks)
+
+    if Puppet::FileSystem.exist?(tasks_directory)
+      @tasks = Puppet::Module::Task.tasks_in_module(self)
+    else
+      @tasks = []
+    end
+  end
+
+  # This is a re-implementation of the Filetypes singular type method (e.g.
+  # `manifest('my/manifest.pp')`. We don't implement the full filetype "API" for
+  # tasks since tasks don't map 1:1 onto files.
+  def task_file(name)
+    # If 'file' is nil then they're asking for the base path.
+    # This is used for things like fileserving.
+    if name
+      full_path = File.join(tasks_directory, name)
+    else
+      full_path = tasks_directory
+    end
+
+    if Puppet::FileSystem.exist?(full_path)
+      return full_path
+    else
+      return nil
+    end
+  end
+
   def license_file
     return @license_file if defined?(@license_file)
 
@@ -402,19 +428,26 @@ class Puppet::Module
 
     locales_path = File.absolute_path('locales', path)
 
-    begin
-      GettextSetup.initialize(locales_path)
+    if Puppet::GettextConfig.initialize(locales_path, :po)
       Puppet.debug "#{module_name} initialized for i18n: #{GettextSetup.translation_repositories[module_name]}"
-    rescue
-      config_path = File.absolute_path('config.yaml', locales_path)
-      Puppet.debug "Could not find locales configuration file for #{module_name} at #{config_path}. Skipping i18n initialization."
+    else if Puppet::GettextConfig.gettext_loaded?
+        config_path = File.absolute_path('config.yaml', locales_path)
+        Puppet.debug "Could not find locales configuration file for #{module_name} at #{config_path}. Skipping i18n initialization."
+    else
+        Puppet.debug "No gettext library found, skipping i18n initialization."
+      end
     end
   end
 
   private
 
   def i18n_initialized?(module_name)
-    GettextSetup.translation_repositories.has_key? module_name
+    if Puppet::GettextConfig.gettext_loaded?
+      GettextSetup.translation_repositories.has_key? module_name
+    else
+      # GettextSetup not yet initialized or not found
+      false
+    end
   end
 
   def wanted_manifests_from(pattern)
