@@ -431,6 +431,32 @@ class Factory
   end
 
   def build_TypeAlias(o, name, type_expr)
+    if type_expr.model_class <= KeyedEntry
+      # KeyedEntry is used for the form:
+      #
+      #   type Foo = Bar { ... }
+      #
+      # The entry contains Bar => { ... } and must be transformed into:
+      #
+      #   Object[{parent => Bar, ... }]
+      #
+      parent = type_expr['key']
+      hash = type_expr['value']
+      unless parent['cased_value'] == 'Object'
+        hash['entries'] << Factory.KEY_ENTRY(Factory.QNAME('parent'), parent)
+      end
+      type_expr = Factory.QREF('Object').access([hash])
+    elsif type_expr.model_class <= LiteralHash
+      # LiteralHash is used for the form:
+      #
+      #   type Foo = { ... }
+      #
+      # The hash must be transformed into:
+      #
+      #   Object[{ ... }]
+      #
+      type_expr = Factory.QREF('Object').access([type_expr])
+    end
     @init_hash['type_expr'] = type_expr
     @init_hash[KEY_NAME] = name
   end
@@ -845,8 +871,22 @@ class Factory
   end
 
   # Builds a BlockExpression if args size > 1, else the single expression/value in args
-  def self.block_or_expression(args)
-    args.size > 1 ? new(BlockExpression, args) : args[0]
+  def self.block_or_expression(args, left_brace = nil, right_brace = nil)
+    if args.size > 1
+      block_expr = new(BlockExpression, args)
+
+      # If given a left and right brace position, use those
+      # otherwise use the first and last element of the block
+      if !left_brace.nil? && !right_brace.nil?
+        block_expr.record_position(args.first[KEY_LOCATOR], left_brace, right_brace)
+      else
+        block_expr.record_position(args.first[KEY_LOCATOR], args.first, args.last)
+      end
+
+      block_expr
+    else
+      args[0]
+    end
   end
 
   def self.HOSTCLASS(name, parameters, parent, body)
