@@ -512,6 +512,7 @@ class TypeCalculator
       o._pcore_type
     else
       name = o.class.name
+      return PRuntimeType.new(:ruby, nil) if name.nil? # anonymous class that doesn't implement PuppetObject is impossible to infer
       ir = Loaders.implementation_registry
       type = ir.nil? ? nil : ir.type_for_module(name)
       type.nil? ? PRuntimeType.new(:ruby, name) : type
@@ -550,7 +551,7 @@ class TypeCalculator
 
   # @api private
   def infer_Regexp(o)
-    PRegexpType.new(o.source)
+    PRegexpType.new(o)
   end
 
   # @api private
