@@ -131,6 +131,9 @@ class PAnyType < TypedModelObject
     when PVariantType
       # Assignable if all contained types are assignable
       o.types.all? { |vt| assignable?(vt, guard) }
+    when POptionalType
+      # Assignable if undef and contained type is assignable
+      assignable?(PUndefType::DEFAULT) && (o.type.nil? || assignable?(o.type))
     when PNotUndefType
       if !(o.type.nil? || o.type.assignable?(PUndefType::DEFAULT))
         assignable?(o.type, guard)
@@ -661,7 +664,9 @@ class PDefaultType < PAnyType
   end
 
   def instance?(o, guard = nil)
-    o == :default
+    # Ensure that Symbol.== is called here instead of something unknown
+    # that is implemented on o
+    :default == o
   end
 
   DEFAULT = PDefaultType.new
@@ -701,7 +706,16 @@ class PScalarType < PAnyType
 
   # @api private
   def _assignable?(o, guard)
-    o.is_a?(PScalarType)
+    o.is_a?(PScalarType) ||
+      PStringType::DEFAULT.assignable?(o, guard) ||
+      PIntegerType::DEFAULT.assignable?(o, guard) ||
+      PFloatType::DEFAULT.assignable?(o, guard) ||
+      PBooleanType::DEFAULT.assignable?(o, guard) ||
+      PRegexpType::DEFAULT.assignable?(o, guard) ||
+      PSemVerType::DEFAULT.assignable?(o, guard) ||
+      PSemVerRangeType::DEFAULT.assignable?(o, guard) ||
+      PTimespanType::DEFAULT.assignable?(o, guard) ||
+      PTimestampType::DEFAULT.assignable?(o, guard)
   end
 end
 
@@ -723,7 +737,11 @@ class PScalarDataType < PScalarType
 
   # @api private
   def _assignable?(o, guard)
-    o.is_a?(PScalarDataType)
+    o.is_a?(PScalarDataType) ||
+      PStringType::DEFAULT.assignable?(o, guard) ||
+      PIntegerType::DEFAULT.assignable?(o, guard) ||
+      PFloatType::DEFAULT.assignable?(o, guard) ||
+      PBooleanType::DEFAULT.assignable?(o, guard)
   end
 end
 
@@ -1485,9 +1503,9 @@ class PStringType < PScalarDataType
   def self.new_function(type)
     @new_function ||= Puppet::Functions.create_loaded_function(:new_string, type.loader) do
       local_types do
-        type 'Format = Pattern[/^%([\s\+\-#0\[\{<\(\|]*)([1-9][0-9]*)?(?:\.([0-9]+))?([a-zA-Z])/]'
+        type "Format = Pattern[/#{StringConverter::Format::FMT_PATTERN_STR}/]"
         type 'ContainerFormat = Struct[{
-          Optional[format]         => String,
+          Optional[format]         => Format,
           Optional[separator]      => String,
           Optional[separator2]     => String,
           Optional[string_formats] => Hash[Type, Format]
@@ -1592,10 +1610,64 @@ class PRegexpType < PScalarType
 
   attr_reader :pattern
 
+  # @param regexp [Regexp] the regular expression
+  # @return [String] the Regexp as a slash delimited string with slashes escaped
+  def self.regexp_to_s_with_delimiters(regexp)
+    regexp.options == 0 ? regexp.inspect : "/#{regexp.to_s}/"
+  end
+
+  # @param regexp [Regexp] the regular expression
+  # @return [String] the Regexp as a string without escaped slash
+  def self.regexp_to_s(regexp)
+    # Rubies < 2.0.0 retains escaped delimiters in the source string.
+    @source_retains_escaped_slash ||= Gem::Version.new(RUBY_VERSION.dup) < Gem::Version.new('2.0.0')
+    source = regexp.source
+    if @source_retains_escaped_slash && source.include?('\\')
+      # Restore corrupt string in rubies <2.0.0, i.e. turn '\/' into '/' but
+      # don't touch valid escapes such as '\s', '\{' etc.
+      escaped = false
+      bld = ''
+      source.each_codepoint do |codepoint|
+        if escaped
+          bld << 0x5c unless codepoint == 0x2f # '/'
+          bld << codepoint
+          escaped = false
+        elsif codepoint == 0x5c # '\'
+          escaped = true
+        elsif codepoint <= 0x7f
+          bld << codepoint
+        else
+          bld << [codepoint].pack('U')
+        end
+      end
+      source = bld
+    end
+    append_flags_group(source, regexp.options)
+  end
+
+  def self.append_flags_group(rx_string, options)
+    if options == 0
+      rx_string
+    else
+      bld = '(?'
+      bld << 'i' if (options & Regexp::IGNORECASE) != 0
+      bld << 'm' if (options & Regexp::MULTILINE) != 0
+      bld << 'x' if (options & Regexp::EXTENDED) != 0
+      unless options == (Regexp::IGNORECASE | Regexp::MULTILINE | Regexp::EXTENDED)
+        bld << '-'
+        bld << 'i' if (options & Regexp::IGNORECASE) == 0
+        bld << 'm' if (options & Regexp::MULTILINE) == 0
+        bld << 'x' if (options & Regexp::EXTENDED) == 0
+      end
+      bld << ':' << rx_string << ')'
+      bld.freeze
+    end
+  end
+
   def initialize(pattern)
     if pattern.is_a?(Regexp)
       @regexp = pattern
-      @pattern = pattern.options == 0 ? pattern.source : pattern.to_s
+      @pattern = PRegexpType.regexp_to_s(pattern)
     else
       @pattern = pattern
     end
@@ -1614,7 +1686,7 @@ class PRegexpType < PScalarType
   end
 
   def instance?(o, guard=nil)
-    o.is_a?(Regexp) && (@pattern.nil? || @pattern == (o.options == 0 ? o.source : o.to_s))
+    o.is_a?(Regexp) && @pattern.nil? || regexp == o
   end
 
   DEFAULT = PRegexpType.new(nil)
@@ -2850,21 +2922,8 @@ class PVariantType < PAnyType
 
   # @api private
   def _assignable?(o, guard)
-    if o.is_a?(PVariantType)
-      # A variant is assignable if all of its options are assignable to one of this type's options
-      return true if self == o
-      o.types.all? do |other|
-        # if the other is a Variant, all of its options, but be assignable to one of this type's options
-        if other.is_a?(PVariantType)
-          assignable?(other, guard)
-        else
-          types.any? {|option_t| option_t.assignable?(other, guard) }
-        end
-      end
-    else
-      # A variant is assignable if o is assignable to any of its types
-      types.any? { |option_t| option_t.assignable?(o, guard) }
-    end
+    # A variant is assignable if o is assignable to any of its types
+    types.any? { |option_t| option_t.assignable?(o, guard) }
   end
 
   # @api private
