@@ -22,6 +22,12 @@ class Puppet::Provider::NameService::DirectoryService < Puppet::Provider::NameSe
   confine :feature         => :cfpropertylist
   defaultfor :operatingsystem => :darwin
 
+  # There is no generalized mechanism for provider cache management, but we can
+  # use post_resource_eval, which will be run for each suitable provider at the
+  # end of each transaction. Use this to clear @all_present after each run.
+  def self.post_resource_eval
+    @all_present = nil
+  end
 
   # JJM 2007-07-25: This map is used to map NameService attributes to their
   #     corresponding DirectoryService attribute names.
@@ -87,13 +93,15 @@ class Puppet::Provider::NameService::DirectoryService < Puppet::Provider::NameSe
   end
 
   def self.list_all_present
-    # JJM: List all objects of this Puppet::Type already present on the system.
-    begin
-      dscl_output = execute(get_exec_preamble("-list"))
-    rescue Puppet::ExecutionFailure
-      fail("Could not get #{@resource_type.name} list from DirectoryService")
+    @all_present ||= begin
+      # JJM: List all objects of this Puppet::Type already present on the system.
+      begin
+        dscl_output = execute(get_exec_preamble("-list"))
+      rescue Puppet::ExecutionFailure
+        fail(_("Could not get %{resource} list from DirectoryService") % { resource: @resource_type.name })
+      end
+      dscl_output.split("\n")
     end
-    dscl_output.split("\n")
   end
 
   def self.parse_dscl_plist_data(dscl_output)
@@ -102,7 +110,7 @@ class Puppet::Provider::NameService::DirectoryService < Puppet::Provider::NameSe
 
   def self.generate_attribute_hash(input_hash, *type_properties)
     attribute_hash = {}
-    input_hash.keys.each do |key|
+    input_hash.each_key do |key|
       ds_attribute = key.sub("dsAttrTypeStandard:", "")
       next unless (ds_to_ns_attribute_map.keys.include?(ds_attribute) and type_properties.include? ds_to_ns_attribute_map[ds_attribute])
       ds_value = input_hash[key]
@@ -149,7 +157,7 @@ class Puppet::Provider::NameService::DirectoryService < Puppet::Provider::NameSe
     begin
       dscl_output = execute(dscl_vector)
     rescue Puppet::ExecutionFailure
-      fail("Could not get report.  command execution failed.")
+      fail(_("Could not get report.  command execution failed."))
     end
 
     dscl_plist = self.parse_dscl_plist_data(dscl_output)
@@ -188,8 +196,8 @@ class Puppet::Provider::NameService::DirectoryService < Puppet::Provider::NameSe
     # zeroes. If someone attempts to use a password hash that worked with
     # a previous version of OS X, we will fail early and warn them.
     if password_hash.length != 136
-      fail("OS X 10.7 requires a Salted SHA512 hash password of 136 characters. \
-           Please check your password and try again.")
+      fail(_("OS X 10.7 requires a Salted SHA512 hash password of 136 characters. \
+           Please check your password and try again."))
     end
 
     plist_file = "#{users_plist_dir}/#{resource_name}.plist"
@@ -276,7 +284,7 @@ class Puppet::Provider::NameService::DirectoryService < Puppet::Provider::NameSe
     elsif id_type == 'gid'
       dscl_args << '/Groups' << 'gid'
     else
-      fail("Invalid id_type #{id_type}. Only 'uid' and 'gid' supported")
+      fail(_("Invalid id_type %{id_type}. Only 'uid' and 'gid' supported") % { id_type: id_type })
     end
     dscl_out = dscl(dscl_args)
     # We're ok with throwing away negative uids here.
@@ -325,7 +333,7 @@ class Puppet::Provider::NameService::DirectoryService < Puppet::Provider::NameSe
       guid = guid_plist["dsAttrTypeStandard:#{ns_to_ds_attribute_map[:guid]}"][0]
       self.class.set_password(@resource.name, guid, passphrase)
     rescue Puppet::ExecutionFailure => detail
-      fail("Could not set #{param} on #{@resource.class.name}[#{@resource.name}]: #{detail}")
+      fail(_("Could not set %{param} on %{resource}[%{name}]: %{detail}") % { param: param, resource: @resource.class.name, name: @resource.name, detail: detail })
     end
   end
 
@@ -354,7 +362,7 @@ class Puppet::Provider::NameService::DirectoryService < Puppet::Provider::NameSe
       begin
         execute(exec_arg_vector)
       rescue Puppet::ExecutionFailure => detail
-        fail("Could not set #{param} on #{@resource.class.name}[#{@resource.name}]: #{detail}")
+        fail(_("Could not set %{param} on %{resource}[%{name}]: %{detail}") % { param: param, resource: @resource.class.name, name: @resource.name, detail: detail })
       end
     end
   end
@@ -381,7 +389,7 @@ class Puppet::Provider::NameService::DirectoryService < Puppet::Provider::NameSe
     begin
       execute(exec_arg_vector)
     rescue Puppet::ExecutionFailure => detail
-      fail("Could not set GeneratedUID for #{@resource.class.name} #{@resource.name}: #{detail}")
+      fail(_("Could not set GeneratedUID for %{resource} %{name}: %{detail}") % { resource: @resource.class.name, name: @resource.name, detail: detail })
     end
 
     if value = @resource.should(:password) and value != ""
@@ -409,7 +417,7 @@ class Puppet::Provider::NameService::DirectoryService < Puppet::Provider::NameSe
           begin
             execute(exec_arg_vector)
           rescue Puppet::ExecutionFailure => detail
-            fail("Could not create #{@resource.class.name} #{@resource.name}: #{detail}")
+            fail(_("Could not create %{resource} %{name}: %{detail}") % { resource: @resource.class.name, name: @resource.name, detail: detail })
           end
         end
       end
@@ -429,7 +437,7 @@ class Puppet::Provider::NameService::DirectoryService < Puppet::Provider::NameSe
           begin
             execute(cmd)
           rescue Puppet::ExecutionFailure => detail
-            fail("Could not remove #{member} from group: #{@resource.name}, #{detail}")
+            fail(_("Could not remove %{member} from group: %{resource}, %{detail}") % { member: member, resource: @resource.name, detail: detail })
           end
         end
       end
@@ -443,7 +451,7 @@ class Puppet::Provider::NameService::DirectoryService < Puppet::Provider::NameSe
         begin
           execute(cmd)
         rescue Puppet::ExecutionFailure => detail
-          fail("Could not add #{new_member} to group: #{@resource.name}, #{detail}")
+          fail(_("Could not add %{new_member} to group: %{name}, %{detail}") % { new_member: new_member, name: @resource.name, detail: detail })
         end
       end
     end
